@@ -48,7 +48,7 @@ def process_assets(file_path: str, lines: List[Tuple[int, str]], asset_dir: str,
 
 def update_markdown_content(asset_dir, file_path, lines, relative_asset_dir):
     if DEBUG:
-        print('processing %s' % file_path)
+        print('updating %s' % file_path)
     with open(file_path) as md:
         content = md.readlines()
         for number, line in lines:
@@ -82,6 +82,8 @@ def ensure_assets_dir_exists(assets_dir):
 def process_file(assets_dir, assets_from_page_dir, file, subdir):
     if file.endswith('.md'):
         file_path = os.path.join(subdir, file)
+        if DEBUG:
+            print('processing %s' % file_path)
         with open(file_path) as md:
             try:
                 numbered_lines = enumerate(line for line in md)
